# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import bess_msg_pb2 as bess__msg__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='service.proto',
  package='bess.pb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\rservice.proto\x12\x07\x62\x65ss.pb\x1a\x0e\x62\x65ss_msg.proto2\xd4\x1b\n\x0b\x42\x45SSControl\x12?\n\nGetVersion\x12\x15.bess.pb.EmptyRequest\x1a\x18.bess.pb.VersionResponse\"\x00\x12;\n\x08ResetAll\x12\x15.bess.pb.EmptyRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12;\n\x08KillBess\x12\x15.bess.pb.EmptyRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12\x46\n\x0cImportPlugin\x12\x1c.bess.pb.ImportPluginRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12\x46\n\x0cUnloadPlugin\x12\x1c.bess.pb.UnloadPluginRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12\x44\n\x0bListPlugins\x12\x15.bess.pb.EmptyRequest\x1a\x1c.bess.pb.ListPluginsResponse\"\x00\x12;\n\x08PauseAll\x12\x15.bess.pb.EmptyRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12\x44\n\x0bPauseWorker\x12\x1b.bess.pb.PauseWorkerRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12\x46\n\x0cResumeWorker\x12\x1c.bess.pb.ResumeWorkerRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12<\n\tResumeAll\x12\x15.bess.pb.EmptyRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12?\n\x0cResetWorkers\x12\x15.bess.pb.EmptyRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12\x44\n\x0bListWorkers\x12\x15.bess.pb.EmptyRequest\x1a\x1c.bess.pb.ListWorkersResponse\"\x00\x12@\n\tAddWorker\x12\x19.bess.pb.AddWorkerRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12H\n\rDestroyWorker\x12\x1d.bess.pb.DestroyWorkerRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12;\n\x08ResetTcs\x12\x15.bess.pb.EmptyRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12>\n\x07ListTcs\x12\x17.bess.pb.ListTcsRequest\x1a\x18.bess.pb.ListTcsResponse\"\x00\x12\x62\n\x1a\x43heckSchedulingConstraints\x12\x15.bess.pb.EmptyRequest\x1a+.bess.pb.CheckSchedulingConstraintsResponse\"\x00\x12\x38\n\x05\x41\x64\x64Tc\x12\x15.bess.pb.AddTcRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12J\n\x0eUpdateTcParams\x12\x1e.bess.pb.UpdateTcParamsRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12J\n\x0eUpdateTcParent\x12\x1e.bess.pb.UpdateTcParentRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12G\n\nGetTcStats\x12\x1a.bess.pb.GetTcStatsRequest\x1a\x1b.bess.pb.GetTcStatsResponse\"\x00\x12\x44\n\x0bListDrivers\x12\x15.bess.pb.EmptyRequest\x1a\x1c.bess.pb.ListDriversResponse\"\x00\x12P\n\rGetDriverInfo\x12\x1d.bess.pb.GetDriverInfoRequest\x1a\x1e.bess.pb.GetDriverInfoResponse\"\x00\x12=\n\nResetPorts\x12\x15.bess.pb.EmptyRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12@\n\tListPorts\x12\x15.bess.pb.EmptyRequest\x1a\x1a.bess.pb.ListPortsResponse\"\x00\x12G\n\nCreatePort\x12\x1a.bess.pb.CreatePortRequest\x1a\x1b.bess.pb.CreatePortResponse\"\x00\x12\x44\n\x0b\x44\x65stroyPort\x12\x1b.bess.pb.DestroyPortRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12\x46\n\x0bSetPortConf\x12\x1b.bess.pb.SetPortConfRequest\x1a\x18.bess.pb.CommandResponse\"\x00\x12J\n\x0bGetPortConf\x12\x1b.bess.pb.GetPortConfRequest\x1a\x1c.bess.pb.GetPortConfResponse\"\x00\x12M\n\x0cGetPortStats\x12\x1c.bess.pb.GetPortStatsRequest\x1a\x1d.bess.pb.GetPortStatsResponse\"\x00\x12P\n\rGetLinkStatus\x12\x1d.bess.pb.GetLinkStatusRequest\x1a\x1e.bess.pb.GetLinkStatusResponse\"\x00\x12\x42\n\nListMclass\x12\x15.bess.pb.EmptyRequest\x1a\x1b.bess.pb.ListMclassResponse\"\x00\x12P\n\rGetMclassInfo\x12\x1d.bess.pb.GetMclassInfoRequest\x1a\x1e.bess.pb.GetMclassInfoResponse\"\x00\x12?\n\x0cResetModules\x12\x15.bess.pb.EmptyRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12\x44\n\x0bListModules\x12\x15.bess.pb.EmptyRequest\x1a\x1c.bess.pb.ListModulesResponse\"\x00\x12M\n\x0c\x43reateModule\x12\x1c.bess.pb.CreateModuleRequest\x1a\x1d.bess.pb.CreateModuleResponse\"\x00\x12H\n\rDestroyModule\x12\x1d.bess.pb.DestroyModuleRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12P\n\rGetModuleInfo\x12\x1d.bess.pb.GetModuleInfoRequest\x1a\x1e.bess.pb.GetModuleInfoResponse\"\x00\x12J\n\x0e\x43onnectModules\x12\x1e.bess.pb.ConnectModulesRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12P\n\x11\x44isconnectModules\x12!.bess.pb.DisconnectModulesRequest\x1a\x16.bess.pb.EmptyResponse\"\x00\x12J\n\x0b\x44umpMempool\x12\x1b.bess.pb.DumpMempoolRequest\x1a\x1c.bess.pb.DumpMempoolResponse\"\x00\x12\x44\n\rModuleCommand\x12\x17.bess.pb.CommandRequest\x1a\x18.bess.pb.CommandResponse\"\x00\x12P\n\x11ListGateHookClass\x12\x15.bess.pb.EmptyRequest\x1a\".bess.pb.ListGateHookClassResponse\"\x00\x12\x65\n\x14GetGateHookClassInfo\x12$.bess.pb.GetGateHookClassInfoRequest\x1a%.bess.pb.GetGateHookClassInfoResponse\"\x00\x12\\\n\x11\x43onfigureGateHook\x12!.bess.pb.ConfigureGateHookRequest\x1a\".bess.pb.ConfigureGateHookResponse\"\x00\x12H\n\rListGateHooks\x12\x15.bess.pb.EmptyRequest\x1a\x1e.bess.pb.ListGateHooksResponse\"\x00\x12N\n\x0fGateHookCommand\x12\x1f.bess.pb.GateHookCommandRequest\x1a\x18.bess.pb.CommandResponse\"\x00\x12V\n\x13\x43onfigureResumeHook\x12#.bess.pb.ConfigureResumeHookRequest\x1a\x18.bess.pb.CommandResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[bess__msg__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_BESSCONTROL = _descriptor.ServiceDescriptor(
  name='BESSControl',
  full_name='bess.pb.BESSControl',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=43,
  serialized_end=3583,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetVersion',
    full_name='bess.pb.BESSControl.GetVersion',
    index=0,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._VERSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ResetAll',
    full_name='bess.pb.BESSControl.ResetAll',
    index=1,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='KillBess',
    full_name='bess.pb.BESSControl.KillBess',
    index=2,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ImportPlugin',
    full_name='bess.pb.BESSControl.ImportPlugin',
    index=3,
    containing_service=None,
    input_type=bess__msg__pb2._IMPORTPLUGINREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UnloadPlugin',
    full_name='bess.pb.BESSControl.UnloadPlugin',
    index=4,
    containing_service=None,
    input_type=bess__msg__pb2._UNLOADPLUGINREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListPlugins',
    full_name='bess.pb.BESSControl.ListPlugins',
    index=5,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._LISTPLUGINSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PauseAll',
    full_name='bess.pb.BESSControl.PauseAll',
    index=6,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PauseWorker',
    full_name='bess.pb.BESSControl.PauseWorker',
    index=7,
    containing_service=None,
    input_type=bess__msg__pb2._PAUSEWORKERREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeWorker',
    full_name='bess.pb.BESSControl.ResumeWorker',
    index=8,
    containing_service=None,
    input_type=bess__msg__pb2._RESUMEWORKERREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeAll',
    full_name='bess.pb.BESSControl.ResumeAll',
    index=9,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ResetWorkers',
    full_name='bess.pb.BESSControl.ResetWorkers',
    index=10,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListWorkers',
    full_name='bess.pb.BESSControl.ListWorkers',
    index=11,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._LISTWORKERSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddWorker',
    full_name='bess.pb.BESSControl.AddWorker',
    index=12,
    containing_service=None,
    input_type=bess__msg__pb2._ADDWORKERREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DestroyWorker',
    full_name='bess.pb.BESSControl.DestroyWorker',
    index=13,
    containing_service=None,
    input_type=bess__msg__pb2._DESTROYWORKERREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ResetTcs',
    full_name='bess.pb.BESSControl.ResetTcs',
    index=14,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListTcs',
    full_name='bess.pb.BESSControl.ListTcs',
    index=15,
    containing_service=None,
    input_type=bess__msg__pb2._LISTTCSREQUEST,
    output_type=bess__msg__pb2._LISTTCSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CheckSchedulingConstraints',
    full_name='bess.pb.BESSControl.CheckSchedulingConstraints',
    index=16,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._CHECKSCHEDULINGCONSTRAINTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddTc',
    full_name='bess.pb.BESSControl.AddTc',
    index=17,
    containing_service=None,
    input_type=bess__msg__pb2._ADDTCREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTcParams',
    full_name='bess.pb.BESSControl.UpdateTcParams',
    index=18,
    containing_service=None,
    input_type=bess__msg__pb2._UPDATETCPARAMSREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTcParent',
    full_name='bess.pb.BESSControl.UpdateTcParent',
    index=19,
    containing_service=None,
    input_type=bess__msg__pb2._UPDATETCPARENTREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTcStats',
    full_name='bess.pb.BESSControl.GetTcStats',
    index=20,
    containing_service=None,
    input_type=bess__msg__pb2._GETTCSTATSREQUEST,
    output_type=bess__msg__pb2._GETTCSTATSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListDrivers',
    full_name='bess.pb.BESSControl.ListDrivers',
    index=21,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._LISTDRIVERSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDriverInfo',
    full_name='bess.pb.BESSControl.GetDriverInfo',
    index=22,
    containing_service=None,
    input_type=bess__msg__pb2._GETDRIVERINFOREQUEST,
    output_type=bess__msg__pb2._GETDRIVERINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ResetPorts',
    full_name='bess.pb.BESSControl.ResetPorts',
    index=23,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListPorts',
    full_name='bess.pb.BESSControl.ListPorts',
    index=24,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._LISTPORTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePort',
    full_name='bess.pb.BESSControl.CreatePort',
    index=25,
    containing_service=None,
    input_type=bess__msg__pb2._CREATEPORTREQUEST,
    output_type=bess__msg__pb2._CREATEPORTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DestroyPort',
    full_name='bess.pb.BESSControl.DestroyPort',
    index=26,
    containing_service=None,
    input_type=bess__msg__pb2._DESTROYPORTREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetPortConf',
    full_name='bess.pb.BESSControl.SetPortConf',
    index=27,
    containing_service=None,
    input_type=bess__msg__pb2._SETPORTCONFREQUEST,
    output_type=bess__msg__pb2._COMMANDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPortConf',
    full_name='bess.pb.BESSControl.GetPortConf',
    index=28,
    containing_service=None,
    input_type=bess__msg__pb2._GETPORTCONFREQUEST,
    output_type=bess__msg__pb2._GETPORTCONFRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPortStats',
    full_name='bess.pb.BESSControl.GetPortStats',
    index=29,
    containing_service=None,
    input_type=bess__msg__pb2._GETPORTSTATSREQUEST,
    output_type=bess__msg__pb2._GETPORTSTATSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetLinkStatus',
    full_name='bess.pb.BESSControl.GetLinkStatus',
    index=30,
    containing_service=None,
    input_type=bess__msg__pb2._GETLINKSTATUSREQUEST,
    output_type=bess__msg__pb2._GETLINKSTATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListMclass',
    full_name='bess.pb.BESSControl.ListMclass',
    index=31,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._LISTMCLASSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMclassInfo',
    full_name='bess.pb.BESSControl.GetMclassInfo',
    index=32,
    containing_service=None,
    input_type=bess__msg__pb2._GETMCLASSINFOREQUEST,
    output_type=bess__msg__pb2._GETMCLASSINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ResetModules',
    full_name='bess.pb.BESSControl.ResetModules',
    index=33,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListModules',
    full_name='bess.pb.BESSControl.ListModules',
    index=34,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._LISTMODULESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModule',
    full_name='bess.pb.BESSControl.CreateModule',
    index=35,
    containing_service=None,
    input_type=bess__msg__pb2._CREATEMODULEREQUEST,
    output_type=bess__msg__pb2._CREATEMODULERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DestroyModule',
    full_name='bess.pb.BESSControl.DestroyModule',
    index=36,
    containing_service=None,
    input_type=bess__msg__pb2._DESTROYMODULEREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetModuleInfo',
    full_name='bess.pb.BESSControl.GetModuleInfo',
    index=37,
    containing_service=None,
    input_type=bess__msg__pb2._GETMODULEINFOREQUEST,
    output_type=bess__msg__pb2._GETMODULEINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ConnectModules',
    full_name='bess.pb.BESSControl.ConnectModules',
    index=38,
    containing_service=None,
    input_type=bess__msg__pb2._CONNECTMODULESREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DisconnectModules',
    full_name='bess.pb.BESSControl.DisconnectModules',
    index=39,
    containing_service=None,
    input_type=bess__msg__pb2._DISCONNECTMODULESREQUEST,
    output_type=bess__msg__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DumpMempool',
    full_name='bess.pb.BESSControl.DumpMempool',
    index=40,
    containing_service=None,
    input_type=bess__msg__pb2._DUMPMEMPOOLREQUEST,
    output_type=bess__msg__pb2._DUMPMEMPOOLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ModuleCommand',
    full_name='bess.pb.BESSControl.ModuleCommand',
    index=41,
    containing_service=None,
    input_type=bess__msg__pb2._COMMANDREQUEST,
    output_type=bess__msg__pb2._COMMANDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListGateHookClass',
    full_name='bess.pb.BESSControl.ListGateHookClass',
    index=42,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._LISTGATEHOOKCLASSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetGateHookClassInfo',
    full_name='bess.pb.BESSControl.GetGateHookClassInfo',
    index=43,
    containing_service=None,
    input_type=bess__msg__pb2._GETGATEHOOKCLASSINFOREQUEST,
    output_type=bess__msg__pb2._GETGATEHOOKCLASSINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ConfigureGateHook',
    full_name='bess.pb.BESSControl.ConfigureGateHook',
    index=44,
    containing_service=None,
    input_type=bess__msg__pb2._CONFIGUREGATEHOOKREQUEST,
    output_type=bess__msg__pb2._CONFIGUREGATEHOOKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListGateHooks',
    full_name='bess.pb.BESSControl.ListGateHooks',
    index=45,
    containing_service=None,
    input_type=bess__msg__pb2._EMPTYREQUEST,
    output_type=bess__msg__pb2._LISTGATEHOOKSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GateHookCommand',
    full_name='bess.pb.BESSControl.GateHookCommand',
    index=46,
    containing_service=None,
    input_type=bess__msg__pb2._GATEHOOKCOMMANDREQUEST,
    output_type=bess__msg__pb2._COMMANDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ConfigureResumeHook',
    full_name='bess.pb.BESSControl.ConfigureResumeHook',
    index=47,
    containing_service=None,
    input_type=bess__msg__pb2._CONFIGURERESUMEHOOKREQUEST,
    output_type=bess__msg__pb2._COMMANDRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_BESSCONTROL)

DESCRIPTOR.services_by_name['BESSControl'] = _BESSCONTROL

# @@protoc_insertion_point(module_scope)
